;   Basic.scm - basic tests for gnustep classes from guile
;   Copyright (C) 1998 Free SoftwareFoundation, Inc.
;
;   Written by:  Richard Frith-Macdonald <richard@brainstorm.co.uk>
;   Date: July 1998
;
;   This file is part of the GNUstep project.
;
;   This library is free software; you can redistribute it and/or
;   modify it under the terms of the GNU Library General Public
;   License as published by the Free Software Foundation; either
;   version 2 of the License, or (at your option) any later version.
;   
;   This library is distributed in the hope that it will be useful,
;   but WITHOUT ANY WARRANTY; without even the implied warranty of
;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;   Library General Public License for more details.
;
;   You should have received a copy of the GNU Library General Public
;   License along with this library; if not, write to the Free
;   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

;
;	Define a convenience procedure to check for methods raising
;	expected exceptions.
;
;	This procedure must be invoked with three arguments -
;	    A string describing the operation being performed
;		eg. "Attempting to access boyond the end of a string"
;	    The Gstep-Guile variable representing the exception
;		eg. NSRangeException
;	    The 'thunk' (code) to actually perform the test.
;
(define (test-exception assertion except thunk)
  (define exception-name ([] except cString))
  (greg-testcase (string-append assertion " raises " exception-name) #t
    (lambda ()
      (catch #t
	thunk
        (lambda key
          (greg-dlog "Caught expected exception -" key "\n")
	  (if (string=? (car key) exception-name)
            #t
	    #f
	  )
	)
      )
    )
  )
)

;
;	Define a procedure to test basic object allocation and initialisation
;	operations that should be common to pretty much all classes.
;	Return #t only if all tests pass, otherwise return #f
; 
(define (test-alloc classname)

  (define theClass gstep-nil)
  (define obj0 gstep-nil)
  (define obj1 gstep-nil)
  (define prefix (string-append "Class '" classname "' "))
  (define all-ok #t)

  (if
    (greg-testcase (string-append prefix "exists") #t
      (lambda ()
	(set! theClass (gstep-lookup-class classname))
	(not (equal? theClass gstep-nil))
      )
    )
    (begin
      (if 
	(greg-testcase (string-append prefix "has working alloc") #t
	  (lambda ()
	    (set! obj0 ([] theClass alloc))
	    (not (equal? obj0 gstep-nil))
	  )
	)
	(set! all-ok
	  (and
	    (greg-testcase (string-append prefix "alloc gives correct class") #t
	      (lambda ()
		(gstep-bool->bool ([] obj0 isKindOfClass: theClass))
	      )
	    )
	    (greg-testcase (string-append prefix "has working init") #t
	      (lambda ()
		(set! obj0 ([] ([] theClass alloc) init))
		(gstep-bool->bool ([] obj0 isKindOfClass: theClass))
	      )
	    )
	    (greg-testcase (string-append prefix "has working new") #t
	      (lambda ()
		(set! obj0 ([] theClass new))
		(gstep-bool->bool ([] obj0 isKindOfClass: theClass))
	      )
	    )
	  )
	)
	(set! all-ok #f)
      )

      (if
	(greg-testcase (string-append prefix "has working allocWithZone:") #t
	  (lambda ()
	    (set! obj1 ([] theClass allocWithZone: testZone))
	    (gstep-bool->bool ([] obj1 isKindOfClass: theClass))
	  )
	)
	(greg-testcase (string-append prefix "uses specified zone for alloc") #t
	  (lambda ()
	    (define theZone (NSZoneFromPointer obj1))
	    (greg-dlog "Object zone " theZone "\n")
	    (greg-dlog "Test zone " testZone "\n")
	    (equal? theZone testZone)
	  )
	)
	(set! all-ok #f)
      )
    )
    (set! all-ok #f)
  )
  all-ok
)

