;;
;;   Copyright (C) 2002 Free SoftwareFoundation, Inc.
;;
;;   Written by: Nicola Pero <nicola@brainstorm.co.uk>
;;   Date: March 2002
;;
;;   This file is part of the GNUstep project.
;;
;;   This library is free software; you can redistribute it and/or
;;   modify it under the terms of the GNU Library General Public
;;   License as published by the Free Software Foundation; either
;;   version 2 of the License, or (at your option) any later version.
;;   
;;   This library is distributed in the hope that it will be useful,
;;   but WITHOUT ANY WARRANTY; without even the implied warranty of
;;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;;   Library General Public License for more details.
;;
;;   You should have received a copy of the GNU Library General Public
;;   License along with this library; if not, write to the Free
;;   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

(begin

  ;; GSXMLDocument basics
  (test-for-class "GSXMLDocument +alloc returns a GSXMLDocument" 
		  "GSXMLDocument" ([] "GSXMLDocument" alloc))

  (test-for-class "GSXMLDocument +documentWithVersion returns a GSXMLDocument" 
		  "GSXMLDocument" 
		  ([] "GSXMLDocument" documentWithVersion: ($$ "1.0")))

  (test-for-nil "GSXMLDocument +documentFromData: nil returns nil" 
		([] "GSXMLDocument" documentFrom: gstep-nil))

  ;; GSXMLNode basics
  (test-for-class "GSXMLNode +alloc returns a GSXMLNode"
		  "GSXMLNode" ([] "GSXMLNode" alloc))

  (test-for-class "GSXMLNode +nodeWithNamespace:name: returns a GSXMLNode" 
		  "GSXMLNode" 
		  ([] "GSXMLNode" nodeWithNamespace: gstep-nil  
		   name: ($$ "Nicola")))

  (test-for-nil "GSXMLNode +nodeFromData: nil returns nil" 
		([] "GSXMLNode" nodeFrom: gstep-nil))

  ;; GSXMLNamespace basics
  (test-for-class "GSXMLNamespace +alloc returns a GSXMLNamespace"
		  "GSXMLNamespace" ([] "GSXMLNamespace" alloc))

  (test-for-class 
   "GSXMLNamespace +namespaceWithNode:href:prefix: returns a GSXMLNamespace"
   "GSXMLNamespace" 
   ([] "GSXMLNamespace" namespaceWithNode: gstep-nil
    href: ($$ "http://www.gnustep.org")
    prefix: ($$ "gnustep")))

  (test-for-nil "GSXMLNamespace +namespaceFromData: nil returns nil" 
		([] "GSXMLNamespace" namespaceFrom: gstep-nil))


  ;; Now some basic tasks
  (greg-testcase 
   "Can set a document node as root node" #t
   (lambda ()
     (let*
	 ((document ([] "GSXMLDocument" documentWithVersion: ($$ "1.0")))
	  (node ([] document makeNodeWithNamespace: gstep-nil
		 name: ($$ "nicola")
		 content: gstep-nil)))
       ([] document setRoot: node)
       (gstep-bool ([] ([] document root) isEqual: node))
       )
     )
   )

  (greg-testcase 
   "Can set a new node as root node" #t
   (lambda ()
     (let*
	 ((document ([] "GSXMLDocument" documentWithVersion: ($$ "1.0")))
	  (node ([] "GSXMLNode" nodeWithNamespace: gstep-nil
		 name: ($$ "nicola"))))
       ([] document setRoot: node)
       (display ([] ([] node description) cString))
       (display ([] ([] ([] document root) description) cString))
       (gstep-bool ([] ([] document root) isEqual: node))
       )
     )
   )

  (greg-testcase 
   "Can set a document node (with children) as root node" #t
   (lambda ()
     (let*
	 ((document ([] "GSXMLDocument" documentWithVersion: ($$ "1.0")))
	  (node ([] document makeNodeWithNamespace: gstep-nil
		             name: ($$ "nicola")
		             content: gstep-nil)))
       ([] node makeChildWithNamespace: gstep-nil
	   name: ($$ "paragraph")
	   content: ($$ "Hi this is some text"))
       ([] node makeChildWithNamespace: gstep-nil
	   name: ($$ "paragraph")
	   content: ($$ "Hi this is some more text"))
       ([] node makeChildWithNamespace: gstep-nil
	   name: ($$ "paragraph")
	   content: ($$ "Hi this is even more text"))
       ([] document setRoot: node)
       (gstep-bool ([] ([] document root) isEqual: node))
       )
     )
   )

  (greg-testcase 
   "Can create a node with a namespace" #t
   (lambda ()
     (let*
	 ((namespace ([] "GSXMLNamespace" namespaceWithNode: gstep-nil
		      href: ($$ "http://www.gnustep.org")
		      prefix: ($$ "gnustep")))
	  (node ([] "GSXMLNode" nodeWithNamespace: namespace name: 
		 ($$ "nicola"))))
       (gstep-bool ([] ([] node ns) isEqual: namespace))
       )
     )
   )

  (greg-testcase 
   "Can create a node with a namespace in a document" #t
   (lambda ()
     (let*
	 ((document ([] "GSXMLDocument" documentWithVersion: ($$ "1.0")))
	  (namespace ([] "GSXMLNamespace" namespaceWithNode: gstep-nil
		      href: ($$ "http://www.gnustep.org")
		      prefix: ($$ "gnustep")))
	  (node ([] document makeNodeWithNamespace: namespace
		 name: ($$ "nicola")
		 content: gstep-nil)))
       (gstep-bool ([] ([] node ns) isEqual: namespace))
       )
     )
   )

;; Can't run this test since we can't get the node of a namespace
;  (greg-testcase 
;   "Can create a namespace with a node in a document" #t
;   (lambda ()
;     (let*
;	 ((document ([] "GSXMLDocument" documentWithVersion: ($$ "1.0")))
;	  (node ([] document makeNodeWithNamespace: gstep-nil
;		 name: ($$ "nicola")
;		 content: gstep-nil))
;	  (namespace ([] "GSXMLNamespace" namespaceWithNode: node
;		      href: ($$ "http://www.gnustep.org")
;		      prefix: ($$ "gnustep"))))
;       (gstep-bool ([] ([] namespace node) isEqual: node))
;       )
;     )
;   )

  (greg-testcase 
   "Can create a node with the same namespace as another node" #t
   (lambda ()
     (let*
	 ((namespace ([] "GSXMLNamespace" namespaceWithNode: gstep-nil
		      href: ($$ "http://www.gnustep.org")
		      prefix: ($$ "gnustep")))
	  (node1 ([] "GSXMLNode" nodeWithNamespace: namespace 
		  name: ($$ "nicola")))
	  (node2 ([] "GSXMLNode" nodeWithNamespace: ([] node1 ns) 
		  name: ($$ "nicola"))))
       (gstep-bool ([] ([] node1 ns) isEqual: ([] node2 ns)))
       )
     )
   )

  (greg-testcase 
   "A namespace remembers its prefix" #t
   (lambda ()
     (let*
	 ((document ([] "GSXMLDocument" documentWithVersion: ($$ "1.0")))
	  (namespace ([] "GSXMLNamespace" namespaceWithNode: gstep-nil
		      href: ($$ "http://www.gnustep.org")
		      prefix: ($$ "gnustep"))))
       (gstep-bool ([] ([] namespace prefix) isEqual: ($$ "gnustep")))
       )
     )
   )

  )
